Class: Cerca::Models::APIKeyToolSourceAuth
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Cerca::Models::APIKeyToolSourceAuth
- Defined in:
- lib/cerca/models/api_key_tool_source_auth.rb
Instance Attribute Summary collapse
- #connection_id ⇒ String
-
#inject ⇒ Cerca::Models::AuthInjection::HeaderAuthInjection, Cerca::Models::AuthInjection::QueryAuthInjection
Where an API key or OAuth access token should be injected into outgoing tool-source requests.
- #kind ⇒ Symbol, :api_key
Instance Method Summary collapse
-
#initialize(connection_id:, inject:, kind: :api_key) ⇒ Object
constructor
Some parameter documentations has been truncated, see APIKeyToolSourceAuth for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(connection_id:, inject:, kind: :api_key) ⇒ Object
Some parameter documentations has been truncated, see Cerca::Models::APIKeyToolSourceAuth for more details.
|
|
# File 'lib/cerca/models/api_key_tool_source_auth.rb', line 23
|
Instance Attribute Details
#connection_id ⇒ String
9 |
# File 'lib/cerca/models/api_key_tool_source_auth.rb', line 9 required :connection_id, String, api_name: :connectionId |
#inject ⇒ Cerca::Models::AuthInjection::HeaderAuthInjection, Cerca::Models::AuthInjection::QueryAuthInjection
Where an API key or OAuth access token should be injected into outgoing tool-source requests.
16 |
# File 'lib/cerca/models/api_key_tool_source_auth.rb', line 16 required :inject, union: -> { Cerca::AuthInjection } |
#kind ⇒ Symbol, :api_key
21 |
# File 'lib/cerca/models/api_key_tool_source_auth.rb', line 21 required :kind, const: :api_key |