Class: Cerca::Models::AgentListToolsResponse
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Cerca::Models::AgentListToolsResponse
- Defined in:
- lib/cerca/models/agent_list_tools_response.rb
Overview
Instance Attribute Summary collapse
- #source_warnings ⇒ Array<Cerca::Models::SourceWarning>?
-
#tools ⇒ Array<Cerca::Models::DiscoveredTool, Cerca::Models::ToolDescriptor>
Unified list of runtime and external tools currently available to the agent.
Instance Method Summary collapse
-
#initialize(tools:, source_warnings: nil) ⇒ Object
constructor
Response for GET /agents/agentId/tools.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(tools:, source_warnings: nil) ⇒ Object
Response for GET /agents/agentId/tools. The tools field is an inspection list, not a configuration request field.
|
|
# File 'lib/cerca/models/agent_list_tools_response.rb', line 20
|
Instance Attribute Details
#source_warnings ⇒ Array<Cerca::Models::SourceWarning>?
16 17 18 |
# File 'lib/cerca/models/agent_list_tools_response.rb', line 16 optional :source_warnings, -> { Cerca::Internal::Type::ArrayOf[Cerca::SourceWarning] }, api_name: :sourceWarnings |
#tools ⇒ Array<Cerca::Models::DiscoveredTool, Cerca::Models::ToolDescriptor>
Unified list of runtime and external tools currently available to the agent.
11 |
# File 'lib/cerca/models/agent_list_tools_response.rb', line 11 required :tools, -> { Cerca::Internal::Type::ArrayOf[union: Cerca::Tool] } |