Module: Cerca::Models::ContentBlock

Extended by:
Internal::Type::Union
Defined in:
lib/cerca/models/content_block.rb

Overview

Message content block. The ‘type` field distinguishes text, tool use, tool result, server tool use, and web search result blocks.

Defined Under Namespace

Classes: ServerToolUseContentBlock, TextContentBlock, ToolResultContentBlock, ToolUseContentBlock, WebSearchToolResultContentBlock

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::Union

==, ===, coerce, dump, hash, inspect, to_sorbet_type, variants

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Instance Method Details

#initialize(id:, input:, name:, provider_metadata: nil, type: :server_tool_use) ⇒ Object

Some parameter documentations has been truncated, see ServerToolUseContentBlock for more details.

Parameters:

  • id (String)
  • input (Object)

    Any JSON value. Generated SDKs may expose this value boundary as unknown or Any.

  • name (String)
  • provider_metadata (Hash{Symbol=>Hash{Symbol=>String}}) (defaults to: nil)
  • type (Symbol, :server_tool_use) (defaults to: :server_tool_use)


# File 'lib/cerca/models/content_block.rb', line 40