Class: Cerca::Models::ContentBlock::WebSearchToolResultContentBlock

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/cerca/models/content_block.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(content:, tool_use_id:, type: :web_search_tool_result) ⇒ Object

Some parameter documentations has been truncated, see Cerca::Models::ContentBlock::WebSearchToolResultContentBlock for more details.

Parameters:

  • content (Object)

    Web search result payload. The runtime returns either an array of web search res

  • tool_use_id (String)
  • type (Symbol, :web_search_tool_result) (defaults to: :web_search_tool_result)


# File 'lib/cerca/models/content_block.rb', line 194

Instance Attribute Details

#contentObject

Web search result payload. The runtime returns either an array of web search results or an error object.

Returns:

  • (Object)


182
# File 'lib/cerca/models/content_block.rb', line 182

required :content, Cerca::Internal::Type::Unknown

#tool_use_idString

Returns:

  • (String)


187
# File 'lib/cerca/models/content_block.rb', line 187

required :tool_use_id, String, api_name: :toolUseId

#typeSymbol, :web_search_tool_result

Returns:

  • (Symbol, :web_search_tool_result)


192
# File 'lib/cerca/models/content_block.rb', line 192

required :type, const: :web_search_tool_result