Class: Cerca::Models::EventListForAgentParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/cerca/models/event_list_for_agent_params.rb

Overview

Defined Under Namespace

Modules: History

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(agent_id:, cursor: nil, events: nil, history: nil, limit: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see Cerca::Models::EventListForAgentParams for more details.

Parameters:

  • agent_id (String)
  • cursor (String) (defaults to: nil)

    Opaque pagination cursor returned by a previous request.

  • events (String) (defaults to: nil)

    Comma-separated event type filter.

  • history (Symbol, Cerca::Models::EventListForAgentParams::History) (defaults to: nil)

    When true, starts from the beginning of the retained buffer.

  • limit (String) (defaults to: nil)

    Maximum number of items to return. Defaults to 20 and preserves parseInt semanti

  • request_options (Cerca::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/cerca/models/event_list_for_agent_params.rb', line 40

Instance Attribute Details

#agent_idString

Returns:

  • (String)


13
# File 'lib/cerca/models/event_list_for_agent_params.rb', line 13

required :agent_id, String

#cursorString?

Opaque pagination cursor returned by a previous request.

Returns:

  • (String, nil)


19
# File 'lib/cerca/models/event_list_for_agent_params.rb', line 19

optional :cursor, String

#eventsString?

Comma-separated event type filter.

Returns:

  • (String, nil)


25
# File 'lib/cerca/models/event_list_for_agent_params.rb', line 25

optional :events, String

#historySymbol, ...

When true, starts from the beginning of the retained buffer.



31
# File 'lib/cerca/models/event_list_for_agent_params.rb', line 31

optional :history, enum: -> { Cerca::EventListForAgentParams::History }

#limitString?

Maximum number of items to return. Defaults to 20 and preserves parseInt semantics.

Returns:

  • (String, nil)


38
# File 'lib/cerca/models/event_list_for_agent_params.rb', line 38

optional :limit, String