Class: Cerca::Models::EventListForFleetParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Cerca::Models::EventListForFleetParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/cerca/models/event_list_for_fleet_params.rb
Overview
Defined Under Namespace
Modules: History
Instance Attribute Summary collapse
-
#cursor ⇒ String?
Opaque pagination cursor returned by a previous request.
-
#events ⇒ String?
Comma-separated event type filter.
- #fleet_id ⇒ String
-
#history ⇒ Symbol, ...
When true, starts from the beginning of the retained buffer.
-
#limit ⇒ String?
Maximum number of items to return.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(fleet_id:, cursor: nil, events: nil, history: nil, limit: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see EventListForFleetParams for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(fleet_id:, cursor: nil, events: nil, history: nil, limit: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see Cerca::Models::EventListForFleetParams for more details.
|
|
# File 'lib/cerca/models/event_list_for_fleet_params.rb', line 40
|
Instance Attribute Details
#cursor ⇒ String?
Opaque pagination cursor returned by a previous request.
19 |
# File 'lib/cerca/models/event_list_for_fleet_params.rb', line 19 optional :cursor, String |
#events ⇒ String?
Comma-separated event type filter.
25 |
# File 'lib/cerca/models/event_list_for_fleet_params.rb', line 25 optional :events, String |
#fleet_id ⇒ String
13 |
# File 'lib/cerca/models/event_list_for_fleet_params.rb', line 13 required :fleet_id, String |
#history ⇒ Symbol, ...
When true, starts from the beginning of the retained buffer.
31 |
# File 'lib/cerca/models/event_list_for_fleet_params.rb', line 31 optional :history, enum: -> { Cerca::EventListForFleetParams::History } |
#limit ⇒ String?
Maximum number of items to return. Defaults to 20 and preserves parseInt semantics.
38 |
# File 'lib/cerca/models/event_list_for_fleet_params.rb', line 38 optional :limit, String |