Class: Cerca::Models::EventStreamForFleetParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/cerca/models/event_stream_for_fleet_params.rb

Overview

Defined Under Namespace

Modules: History

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(fleet_id:, cursor: nil, events: nil, history: nil, last_event_id: nil, request_options: {}) ⇒ Object

Parameters:

  • fleet_id (String)
  • cursor (String) (defaults to: nil)

    Opaque pagination cursor returned by a previous request.

  • events (String) (defaults to: nil)

    Comma-separated event type filter.

  • history (Symbol, Cerca::Models::EventStreamForFleetParams::History) (defaults to: nil)

    When true, starts from the beginning of the retained buffer.

  • last_event_id (String) (defaults to: nil)

    Resume an event-log stream after the last received SSE event id.

  • request_options (Cerca::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/cerca/models/event_stream_for_fleet_params.rb', line 39

Instance Attribute Details

#cursorString?

Opaque pagination cursor returned by a previous request.

Returns:

  • (String, nil)


19
# File 'lib/cerca/models/event_stream_for_fleet_params.rb', line 19

optional :cursor, String

#eventsString?

Comma-separated event type filter.

Returns:

  • (String, nil)


25
# File 'lib/cerca/models/event_stream_for_fleet_params.rb', line 25

optional :events, String

#fleet_idString

Returns:

  • (String)


13
# File 'lib/cerca/models/event_stream_for_fleet_params.rb', line 13

required :fleet_id, String

#historySymbol, ...

When true, starts from the beginning of the retained buffer.



31
# File 'lib/cerca/models/event_stream_for_fleet_params.rb', line 31

optional :history, enum: -> { Cerca::EventStreamForFleetParams::History }

#last_event_idString?

Resume an event-log stream after the last received SSE event id.

Returns:

  • (String, nil)


37
# File 'lib/cerca/models/event_stream_for_fleet_params.rb', line 37

optional :last_event_id, String