Class: Cerca::Models::EventStreamForThreadEventsParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/cerca/models/event_stream_for_thread_events_params.rb

Overview

Defined Under Namespace

Modules: History

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(agent_id:, thread_id:, cursor: nil, events: nil, history: nil, last_event_id: nil, request_options: {}) ⇒ Object

Parameters:

  • agent_id (String)
  • thread_id (String)
  • cursor (String) (defaults to: nil)

    Opaque pagination cursor returned by a previous request.

  • events (String) (defaults to: nil)

    Comma-separated event type filter.

  • history (Symbol, Cerca::Models::EventStreamForThreadEventsParams::History) (defaults to: nil)

    When true, starts from the beginning of the retained buffer.

  • last_event_id (String) (defaults to: nil)

    Resume an event-log stream after the last received SSE event id.

  • request_options (Cerca::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/cerca/models/event_stream_for_thread_events_params.rb', line 44

Instance Attribute Details

#agent_idString

Returns:

  • (String)


13
# File 'lib/cerca/models/event_stream_for_thread_events_params.rb', line 13

required :agent_id, String

#cursorString?

Opaque pagination cursor returned by a previous request.

Returns:

  • (String, nil)


24
# File 'lib/cerca/models/event_stream_for_thread_events_params.rb', line 24

optional :cursor, String

#eventsString?

Comma-separated event type filter.

Returns:

  • (String, nil)


30
# File 'lib/cerca/models/event_stream_for_thread_events_params.rb', line 30

optional :events, String

#historySymbol, ...

When true, starts from the beginning of the retained buffer.



36
# File 'lib/cerca/models/event_stream_for_thread_events_params.rb', line 36

optional :history, enum: -> { Cerca::EventStreamForThreadEventsParams::History }

#last_event_idString?

Resume an event-log stream after the last received SSE event id.

Returns:

  • (String, nil)


42
# File 'lib/cerca/models/event_stream_for_thread_events_params.rb', line 42

optional :last_event_id, String

#thread_idString

Returns:

  • (String)


18
# File 'lib/cerca/models/event_stream_for_thread_events_params.rb', line 18

required :thread_id, String