Class: Cerca::Models::OAuthConnectionToolSourceAuth
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Cerca::Models::OAuthConnectionToolSourceAuth
- Defined in:
- lib/cerca/models/oauth_connection_tool_source_auth.rb
Instance Attribute Summary collapse
-
#inject ⇒ Cerca::Models::AuthInjection::HeaderAuthInjection, ...
Where an API key or OAuth access token should be injected into outgoing tool-source requests.
- #kind ⇒ Symbol, :oauth_connection
- #provider ⇒ String
- #required_scopes ⇒ Array<String>?
Instance Method Summary collapse
-
#initialize(provider:, inject: nil, required_scopes: nil, kind: :oauth_connection) ⇒ Object
constructor
Some parameter documentations has been truncated, see OAuthConnectionToolSourceAuth for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(provider:, inject: nil, required_scopes: nil, kind: :oauth_connection) ⇒ Object
Some parameter documentations has been truncated, see Cerca::Models::OAuthConnectionToolSourceAuth for more details.
|
|
# File 'lib/cerca/models/oauth_connection_tool_source_auth.rb', line 28
|
Instance Attribute Details
#inject ⇒ Cerca::Models::AuthInjection::HeaderAuthInjection, ...
Where an API key or OAuth access token should be injected into outgoing tool-source requests.
21 |
# File 'lib/cerca/models/oauth_connection_tool_source_auth.rb', line 21 optional :inject, union: -> { Cerca::AuthInjection } |
#kind ⇒ Symbol, :oauth_connection
9 |
# File 'lib/cerca/models/oauth_connection_tool_source_auth.rb', line 9 required :kind, const: :oauth_connection |
#provider ⇒ String
14 |
# File 'lib/cerca/models/oauth_connection_tool_source_auth.rb', line 14 required :provider, String |