Class: Cerca::Models::OAuthExchangeToolSourceAuth
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Cerca::Models::OAuthExchangeToolSourceAuth
- Defined in:
- lib/cerca/models/oauth_exchange_tool_source_auth.rb
Instance Attribute Summary collapse
-
#exchange ⇒ Cerca::Models::OAuthExchangeConfig::ClientCredentialsOAuthExchange, Cerca::Models::OAuthExchangeConfig::JwtBearerOAuthExchange
Source-owned OAuth exchange configuration.
-
#inject ⇒ Cerca::Models::AuthInjection::HeaderAuthInjection, Cerca::Models::AuthInjection::QueryAuthInjection
Where an API key or OAuth access token should be injected into outgoing tool-source requests.
- #kind ⇒ Symbol, :oauth_exchange
Instance Method Summary collapse
-
#initialize(exchange:, inject:, kind: :oauth_exchange) ⇒ Object
constructor
Some parameter documentations has been truncated, see OAuthExchangeToolSourceAuth for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(exchange:, inject:, kind: :oauth_exchange) ⇒ Object
Some parameter documentations has been truncated, see Cerca::Models::OAuthExchangeToolSourceAuth for more details.
|
|
# File 'lib/cerca/models/oauth_exchange_tool_source_auth.rb', line 25
|
Instance Attribute Details
#exchange ⇒ Cerca::Models::OAuthExchangeConfig::ClientCredentialsOAuthExchange, Cerca::Models::OAuthExchangeConfig::JwtBearerOAuthExchange
Source-owned OAuth exchange configuration. Public schemas use connection IDs for stored client secrets and assertions.
11 |
# File 'lib/cerca/models/oauth_exchange_tool_source_auth.rb', line 11 required :exchange, union: -> { Cerca::OAuthExchangeConfig } |
#inject ⇒ Cerca::Models::AuthInjection::HeaderAuthInjection, Cerca::Models::AuthInjection::QueryAuthInjection
Where an API key or OAuth access token should be injected into outgoing tool-source requests.
18 |
# File 'lib/cerca/models/oauth_exchange_tool_source_auth.rb', line 18 required :inject, union: -> { Cerca::AuthInjection } |
#kind ⇒ Symbol, :oauth_exchange
23 |
# File 'lib/cerca/models/oauth_exchange_tool_source_auth.rb', line 23 required :kind, const: :oauth_exchange |