Class: Cerca::Models::RuntimeWebhookEvent::ThreadStatusChangedWebhookEvent::Data

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/cerca/models/runtime_webhook_event.rb

Overview

See Also:

Instance Attribute Summary collapse

Method Summary

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

This class inherits a constructor from Cerca::Internal::Type::BaseModel

Instance Attribute Details

#errorString?

Returns:

  • (String, nil)


527
# File 'lib/cerca/models/runtime_webhook_event.rb', line 527

required :error, String, nil?: true

#previous_statusSymbol, Cerca::Models::Status

‘idle` threads can accept a new turn or be closed. `running` threads have an active turn. `awaiting` threads are paused on external input such as approvals. `closed` threads are terminal.

Returns:



535
# File 'lib/cerca/models/runtime_webhook_event.rb', line 535

required :previous_status, enum: -> { Cerca::Status }, api_name: :previousStatus

#resultString?

Returns:

  • (String, nil)


540
# File 'lib/cerca/models/runtime_webhook_event.rb', line 540

required :result, String, nil?: true

#statusSymbol, Cerca::Models::Status

‘idle` threads can accept a new turn or be closed. `running` threads have an active turn. `awaiting` threads are paused on external input such as approvals. `closed` threads are terminal.

Returns:



548
# File 'lib/cerca/models/runtime_webhook_event.rb', line 548

required :status, enum: -> { Cerca::Status }