Class: Cerca::Models::ScheduleUpdateParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/cerca/models/schedule_update_params.rb

Overview

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(agent_id:, schedule_id:, cron: nil, enabled: nil, instructions: nil, message: nil, model: nil, name: nil, run_at: nil, timezone: nil, tools: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see Cerca::Models::ScheduleUpdateParams for more details.

Parameters:

  • agent_id (String)
  • schedule_id (String)
  • cron (String) (defaults to: nil)
  • enabled (Boolean) (defaults to: nil)
  • instructions (String) (defaults to: nil)
  • message (String) (defaults to: nil)
  • model (String) (defaults to: nil)
  • name (String) (defaults to: nil)
  • run_at (Time) (defaults to: nil)
  • timezone (String) (defaults to: nil)
  • tools (Array<String>) (defaults to: nil)

    Per-schedule tool subset. When updated, these tools can only narrow the agent’s

  • request_options (Cerca::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/cerca/models/schedule_update_params.rb', line 67

Instance Attribute Details

#agent_idString

Returns:

  • (String)


13
# File 'lib/cerca/models/schedule_update_params.rb', line 13

required :agent_id, String

#cronString?

Returns:

  • (String, nil)


23
# File 'lib/cerca/models/schedule_update_params.rb', line 23

optional :cron, String

#enabledBoolean?

Returns:

  • (Boolean, nil)


28
# File 'lib/cerca/models/schedule_update_params.rb', line 28

optional :enabled, Cerca::Internal::Type::Boolean

#instructionsString?

Returns:

  • (String, nil)


33
# File 'lib/cerca/models/schedule_update_params.rb', line 33

optional :instructions, String

#messageString?

Returns:

  • (String, nil)


38
# File 'lib/cerca/models/schedule_update_params.rb', line 38

optional :message, String

#modelString?

Returns:

  • (String, nil)


43
# File 'lib/cerca/models/schedule_update_params.rb', line 43

optional :model, String

#nameString?

Returns:

  • (String, nil)


48
# File 'lib/cerca/models/schedule_update_params.rb', line 48

optional :name, String

#run_atTime?

Returns:

  • (Time, nil)


53
# File 'lib/cerca/models/schedule_update_params.rb', line 53

optional :run_at, Time, api_name: :runAt

#schedule_idString

Returns:

  • (String)


18
# File 'lib/cerca/models/schedule_update_params.rb', line 18

required :schedule_id, String

#timezoneString?

Returns:

  • (String, nil)


58
# File 'lib/cerca/models/schedule_update_params.rb', line 58

optional :timezone, String

#toolsArray<String>?

Per-schedule tool subset. When updated, these tools can only narrow the agent’s effective tools for future scheduled threads.

Returns:

  • (Array<String>, nil)


65
# File 'lib/cerca/models/schedule_update_params.rb', line 65

optional :tools, Cerca::Internal::Type::ArrayOf[String]