Class: Cerca::Models::SubThreadSummary

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/cerca/models/sub_thread_summary.rb

Defined Under Namespace

Modules: State

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, completed_at:, created_at:, message_count:, model:, parent_thread_id:, result:, schedule_id:, schedule_seq:, state:, step_count:, tool_use_id:) ⇒ Object

Some parameter documentations has been truncated, see Cerca::Models::SubThreadSummary for more details.

Parameters:

  • id (String)
  • completed_at (String, nil)
  • created_at (String)
  • message_count (Float)
  • model (String)
  • parent_thread_id (String, nil)
  • result (String, nil)
  • schedule_id (String, nil)
  • schedule_seq (Float, nil)
  • state (Symbol, Cerca::Models::SubThreadSummary::State)

    ‘pending` means the parent thread is still waiting on this sub-thread. Other val

  • step_count (Float)
  • tool_use_id (String, nil)


# File 'lib/cerca/models/sub_thread_summary.rb', line 68

Instance Attribute Details

#completed_atString?

Returns:

  • (String, nil)


14
# File 'lib/cerca/models/sub_thread_summary.rb', line 14

required :completed_at, String, api_name: :completedAt, nil?: true

#created_atString

Returns:

  • (String)


19
# File 'lib/cerca/models/sub_thread_summary.rb', line 19

required :created_at, String, api_name: :createdAt

#idString

Returns:

  • (String)


9
# File 'lib/cerca/models/sub_thread_summary.rb', line 9

required :id, String

#message_countFloat

Returns:

  • (Float)


24
# File 'lib/cerca/models/sub_thread_summary.rb', line 24

required :message_count, Float, api_name: :messageCount

#modelString

Returns:

  • (String)


29
# File 'lib/cerca/models/sub_thread_summary.rb', line 29

required :model, String

#parent_thread_idString?

Returns:

  • (String, nil)


34
# File 'lib/cerca/models/sub_thread_summary.rb', line 34

required :parent_thread_id, String, api_name: :parentThreadId, nil?: true

#resultString?

Returns:

  • (String, nil)


39
# File 'lib/cerca/models/sub_thread_summary.rb', line 39

required :result, String, nil?: true

#schedule_idString?

Returns:

  • (String, nil)


44
# File 'lib/cerca/models/sub_thread_summary.rb', line 44

required :schedule_id, String, api_name: :scheduleId, nil?: true

#schedule_seqFloat?

Returns:

  • (Float, nil)


49
# File 'lib/cerca/models/sub_thread_summary.rb', line 49

required :schedule_seq, Float, api_name: :scheduleSeq, nil?: true

#stateSymbol, Cerca::Models::SubThreadSummary::State

‘pending` means the parent thread is still waiting on this sub-thread. Other values are the child thread lifecycle state.



56
# File 'lib/cerca/models/sub_thread_summary.rb', line 56

required :state, enum: -> { Cerca::SubThreadSummary::State }

#step_countFloat

Returns:

  • (Float)


61
# File 'lib/cerca/models/sub_thread_summary.rb', line 61

required :step_count, Float, api_name: :stepCount

#tool_use_idString?

Returns:

  • (String, nil)


66
# File 'lib/cerca/models/sub_thread_summary.rb', line 66

required :tool_use_id, String, api_name: :toolUseId, nil?: true