Class: Cerca::Models::ThreadListMessagesParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Cerca::Models::ThreadListMessagesParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/cerca/models/thread_list_messages_params.rb
Overview
Instance Attribute Summary collapse
- #agent_id ⇒ String
-
#cursor ⇒ String?
Cursor returned by a previous thread messages response.
-
#fleet_id ⇒ String?
Optional fleet id for index-backed authorization.
-
#limit ⇒ String?
Maximum number of messages to include, capped at 500.
- #thread_id ⇒ String
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
- #initialize(agent_id:, thread_id:, cursor: nil, fleet_id: nil, limit: nil, request_options: {}) ⇒ Object constructor
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(agent_id:, thread_id:, cursor: nil, fleet_id: nil, limit: nil, request_options: {}) ⇒ Object
|
|
# File 'lib/cerca/models/thread_list_messages_params.rb', line 38
|
Instance Attribute Details
#agent_id ⇒ String
13 |
# File 'lib/cerca/models/thread_list_messages_params.rb', line 13 required :agent_id, String |
#cursor ⇒ String?
Cursor returned by a previous thread messages response.
24 |
# File 'lib/cerca/models/thread_list_messages_params.rb', line 24 optional :cursor, String |
#fleet_id ⇒ String?
Optional fleet id for index-backed authorization.
30 |
# File 'lib/cerca/models/thread_list_messages_params.rb', line 30 optional :fleet_id, String |
#limit ⇒ String?
Maximum number of messages to include, capped at 500.
36 |
# File 'lib/cerca/models/thread_list_messages_params.rb', line 36 optional :limit, String |
#thread_id ⇒ String
18 |
# File 'lib/cerca/models/thread_list_messages_params.rb', line 18 required :thread_id, String |