Class: Cerca::Models::ThreadRetrieveParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Cerca::Models::ThreadRetrieveParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/cerca/models/thread_retrieve_params.rb
Overview
Defined Under Namespace
Modules: Debug, IncludeMessages
Instance Attribute Summary collapse
- #agent_id ⇒ String
-
#debug ⇒ Symbol, ...
When true, includes debug-only compiled context fields.
-
#include_messages ⇒ Symbol, ...
When true, includes message content in the thread detail.
- #thread_id ⇒ String
Attributes included from Internal::Type::RequestParameters
Class Method Summary collapse
Instance Method Summary collapse
- #initialize(agent_id:, thread_id:, debug: nil, include_messages: nil, request_options: {}) ⇒ Object constructor
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(agent_id:, thread_id:, debug: nil, include_messages: nil, request_options: {}) ⇒ Object
|
|
# File 'lib/cerca/models/thread_retrieve_params.rb', line 32
|
Instance Attribute Details
#agent_id ⇒ String
13 |
# File 'lib/cerca/models/thread_retrieve_params.rb', line 13 required :agent_id, String |
#debug ⇒ Symbol, ...
When true, includes debug-only compiled context fields.
24 |
# File 'lib/cerca/models/thread_retrieve_params.rb', line 24 optional :debug, enum: -> { Cerca::ThreadRetrieveParams::Debug } |
#include_messages ⇒ Symbol, ...
When true, includes message content in the thread detail.
30 |
# File 'lib/cerca/models/thread_retrieve_params.rb', line 30 optional :include_messages, enum: -> { Cerca::ThreadRetrieveParams::IncludeMessages } |
#thread_id ⇒ String
18 |
# File 'lib/cerca/models/thread_retrieve_params.rb', line 18 required :thread_id, String |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/cerca/models/thread_retrieve_params.rb', line 50
|