Class: Cerca::Models::ThreadStreamEvent::ThreadStreamStatusMessage

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/cerca/models/thread_stream_event.rb

Instance Attribute Summary collapse

Method Summary

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

This class inherits a constructor from Cerca::Internal::Type::BaseModel

Instance Attribute Details

#errorString?

Returns:

  • (String, nil)


35
# File 'lib/cerca/models/thread_stream_event.rb', line 35

required :error, String, nil?: true

#event_seqFloat

Returns:

  • (Float)


40
# File 'lib/cerca/models/thread_stream_event.rb', line 40

required :event_seq, Float, api_name: :eventSeq

#resultString?

Returns:

  • (String, nil)


45
# File 'lib/cerca/models/thread_stream_event.rb', line 45

required :result, String, nil?: true

#statusSymbol, Cerca::Models::Status

‘idle` threads can accept a new turn or be closed. `running` threads have an active turn. `awaiting` threads are paused on external input such as approvals. `closed` threads are terminal.

Returns:



53
# File 'lib/cerca/models/thread_stream_event.rb', line 53

required :status, enum: -> { Cerca::Status }

#step_seqFloat

Returns:

  • (Float)


58
# File 'lib/cerca/models/thread_stream_event.rb', line 58

required :step_seq, Float, api_name: :stepSeq

#turn_idString

Returns:

  • (String)


63
# File 'lib/cerca/models/thread_stream_event.rb', line 63

required :turn_id, String, api_name: :turnId

#typeSymbol, :status

Returns:

  • (Symbol, :status)


68
# File 'lib/cerca/models/thread_stream_event.rb', line 68

required :type, const: :status