Class: Cerca::Models::ThreadSummary

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/cerca/models/thread_summary.rb

Overview

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, completed_at:, created_at:, message_count:, model:, parent_thread_id:, result:, schedule_id:, schedule_seq:, status:, step_count:) ⇒ Object

Some parameter documentations has been truncated, see Cerca::Models::ThreadSummary for more details.

Parameters:

  • id (String)
  • completed_at (String, nil)
  • created_at (String)
  • message_count (Float)
  • model (String)
  • parent_thread_id (String, nil)
  • result (String, nil)
  • schedule_id (String, nil)
  • schedule_seq (Float, nil)
  • status (Symbol, Cerca::Models::Status)

    ‘idle` threads can accept a new turn or be closed. `running` threads have an act

  • step_count (Float)


# File 'lib/cerca/models/thread_summary.rb', line 65

Instance Attribute Details

#completed_atString?

Returns:

  • (String, nil)


15
# File 'lib/cerca/models/thread_summary.rb', line 15

required :completed_at, String, api_name: :completedAt, nil?: true

#created_atString

Returns:

  • (String)


20
# File 'lib/cerca/models/thread_summary.rb', line 20

required :created_at, String, api_name: :createdAt

#idString

Returns:

  • (String)


10
# File 'lib/cerca/models/thread_summary.rb', line 10

required :id, String

#message_countFloat

Returns:

  • (Float)


25
# File 'lib/cerca/models/thread_summary.rb', line 25

required :message_count, Float, api_name: :messageCount

#modelString

Returns:

  • (String)


30
# File 'lib/cerca/models/thread_summary.rb', line 30

required :model, String

#parent_thread_idString?

Returns:

  • (String, nil)


35
# File 'lib/cerca/models/thread_summary.rb', line 35

required :parent_thread_id, String, api_name: :parentThreadId, nil?: true

#resultString?

Returns:

  • (String, nil)


40
# File 'lib/cerca/models/thread_summary.rb', line 40

required :result, String, nil?: true

#schedule_idString?

Returns:

  • (String, nil)


45
# File 'lib/cerca/models/thread_summary.rb', line 45

required :schedule_id, String, api_name: :scheduleId, nil?: true

#schedule_seqFloat?

Returns:

  • (Float, nil)


50
# File 'lib/cerca/models/thread_summary.rb', line 50

required :schedule_seq, Float, api_name: :scheduleSeq, nil?: true

#statusSymbol, Cerca::Models::Status

‘idle` threads can accept a new turn or be closed. `running` threads have an active turn. `awaiting` threads are paused on external input such as approvals. `closed` threads are terminal.

Returns:



58
# File 'lib/cerca/models/thread_summary.rb', line 58

required :status, enum: -> { Cerca::Status }

#step_countFloat

Returns:

  • (Float)


63
# File 'lib/cerca/models/thread_summary.rb', line 63

required :step_count, Float, api_name: :stepCount