Class: Cerca::Models::ToolDescriptor
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Cerca::Models::ToolDescriptor
- Defined in:
- lib/cerca/models/tool_descriptor.rb
Defined Under Namespace
Modules: ApprovalSource, Category
Instance Attribute Summary collapse
- #approval_source ⇒ Symbol, Cerca::Models::ToolDescriptor::ApprovalSource
- #category ⇒ Symbol, Cerca::Models::ToolDescriptor::Category
- #description ⇒ String
-
#input_schema ⇒ Hash{Symbol=>Object}
JSON Schema object describing tool input parameters.
- #name ⇒ Symbol, Cerca::Models::ToolName
- #requires_approval ⇒ Boolean
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(approval_source:, category:, description:, input_schema:, name:, requires_approval:) ⇒ Object
constructor
A built-in or configurable runtime tool currently available to the agent.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(approval_source:, category:, description:, input_schema:, name:, requires_approval:) ⇒ Object
A built-in or configurable runtime tool currently available to the agent.
|
|
# File 'lib/cerca/models/tool_descriptor.rb', line 39
|
Instance Attribute Details
#approval_source ⇒ Symbol, Cerca::Models::ToolDescriptor::ApprovalSource
9 |
# File 'lib/cerca/models/tool_descriptor.rb', line 9 required :approval_source, enum: -> { Cerca::ToolDescriptor::ApprovalSource }, api_name: :approvalSource |
#category ⇒ Symbol, Cerca::Models::ToolDescriptor::Category
14 |
# File 'lib/cerca/models/tool_descriptor.rb', line 14 required :category, enum: -> { Cerca::ToolDescriptor::Category } |
#description ⇒ String
19 |
# File 'lib/cerca/models/tool_descriptor.rb', line 19 required :description, String |
#input_schema ⇒ Hash{Symbol=>Object}
JSON Schema object describing tool input parameters.
25 26 27 |
# File 'lib/cerca/models/tool_descriptor.rb', line 25 required :input_schema, Cerca::Internal::Type::HashOf[Cerca::Internal::Type::Unknown], api_name: :inputSchema |
#name ⇒ Symbol, Cerca::Models::ToolName
32 |
# File 'lib/cerca/models/tool_descriptor.rb', line 32 required :name, enum: -> { Cerca::ToolName } |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/cerca/models/tool_descriptor.rb', line 62
|