Module: Cerca::Models::Status
- Extended by:
- Internal::Type::Enum
- Defined in:
- lib/cerca/models/status.rb
Overview
‘idle` threads can accept a new turn or be closed. `running` threads have an active turn. `awaiting` threads are paused on external input such as approvals. `closed` threads are terminal.
Constant Summary collapse
- IDLE =
:idle- RUNNING =
:running- AWAITING =
:awaiting- CLOSED =
:closed
Class Method Summary collapse
Methods included from Internal::Type::Enum
==, ===, coerce, dump, hash, inspect, to_sorbet_type, values
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/cerca/models/status.rb', line 16
|