Class: Cerca::Models::SteerResult
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Cerca::Models::SteerResult
- Defined in:
- lib/cerca/models/steer_result.rb
Overview
Defined Under Namespace
Modules: Status
Instance Attribute Summary collapse
- #status ⇒ Symbol, Cerca::Models::SteerResult::Status
-
#thread_status ⇒ Symbol, Cerca::Models::Status
‘idle` threads can accept a new turn or be closed.
- #turn_id ⇒ String
Instance Method Summary collapse
-
#initialize(status:, thread_status:, turn_id:) ⇒ Object
constructor
Some parameter documentations has been truncated, see SteerResult for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(status:, thread_status:, turn_id:) ⇒ Object
Some parameter documentations has been truncated, see Cerca::Models::SteerResult for more details.
|
|
# File 'lib/cerca/models/steer_result.rb', line 25
|
Instance Attribute Details
#status ⇒ Symbol, Cerca::Models::SteerResult::Status
10 |
# File 'lib/cerca/models/steer_result.rb', line 10 required :status, enum: -> { Cerca::SteerResult::Status } |
#thread_status ⇒ Symbol, Cerca::Models::Status
‘idle` threads can accept a new turn or be closed. `running` threads have an active turn. `awaiting` threads are paused on external input such as approvals. `closed` threads are terminal.
18 |
# File 'lib/cerca/models/steer_result.rb', line 18 required :thread_status, enum: -> { Cerca::Status }, api_name: :threadStatus |
#turn_id ⇒ String
23 |
# File 'lib/cerca/models/steer_result.rb', line 23 required :turn_id, String, api_name: :turnId |