Class: Cerca::Models::Thread
Overview
Defined Under Namespace
Modules: ExternalToolNamespaces, LastTurnStatus
Instance Attribute Summary collapse
Class Method Summary
collapse
Instance Method Summary
collapse
-
#initialize(id:, agent_id:, compiled_context:, completed_at:, created_at:, depth:, error:, instructions:, last_turn_status:, message:, messages:, model:, parent_thread_id:, result:, schedule_id:, schedule_seq:, status:, sub_threads:, tools:, turns:, updated_at:, external_tool_namespaces: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see Thread for more details.
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, agent_id:, compiled_context:, completed_at:, created_at:, depth:, error:, instructions:, last_turn_status:, message:, messages:, model:, parent_thread_id:, result:, schedule_id:, schedule_seq:, status:, sub_threads:, tools:, turns:, updated_at:, external_tool_namespaces: nil) ⇒ Object
|
# File 'lib/cerca/models/thread.rb', line 127
|
Instance Attribute Details
#agent_id ⇒ String
15
|
# File 'lib/cerca/models/thread.rb', line 15
required :agent_id, String, api_name: :agentId
|
20
|
# File 'lib/cerca/models/thread.rb', line 20
required :compiled_context, -> { Cerca::CompiledContext }, api_name: :compiledContext, nil?: true
|
#completed_at ⇒ String?
25
|
# File 'lib/cerca/models/thread.rb', line 25
required :completed_at, String, api_name: :completedAt, nil?: true
|
#created_at ⇒ String
30
|
# File 'lib/cerca/models/thread.rb', line 30
required :created_at, String, api_name: :createdAt
|
#depth ⇒ Float
35
|
# File 'lib/cerca/models/thread.rb', line 35
required :depth, Float
|
#error ⇒ String?
40
|
# File 'lib/cerca/models/thread.rb', line 40
required :error, String, nil?: true
|
123
124
125
|
# File 'lib/cerca/models/thread.rb', line 123
optional :external_tool_namespaces,
union: -> { Cerca::Thread::ExternalToolNamespaces },
api_name: :externalToolNamespaces
|
#id ⇒ String
10
|
# File 'lib/cerca/models/thread.rb', line 10
required :id, String
|
#instructions ⇒ String?
45
|
# File 'lib/cerca/models/thread.rb', line 45
required :instructions, String, nil?: true
|
#last_turn_status ⇒ Symbol, ...
50
51
52
53
|
# File 'lib/cerca/models/thread.rb', line 50
required :last_turn_status,
enum: -> { Cerca::Thread::LastTurnStatus },
api_name: :lastTurnStatus,
nil?: true
|
#message ⇒ String
58
|
# File 'lib/cerca/models/thread.rb', line 58
required :message, String
|
#model ⇒ String
68
|
# File 'lib/cerca/models/thread.rb', line 68
required :model, String
|
#parent_thread_id ⇒ String?
73
|
# File 'lib/cerca/models/thread.rb', line 73
required :parent_thread_id, String, api_name: :parentThreadId, nil?: true
|
#result ⇒ String?
78
|
# File 'lib/cerca/models/thread.rb', line 78
required :result, String, nil?: true
|
#schedule_id ⇒ String?
83
|
# File 'lib/cerca/models/thread.rb', line 83
required :schedule_id, String, api_name: :scheduleId, nil?: true
|
#schedule_seq ⇒ Float?
88
|
# File 'lib/cerca/models/thread.rb', line 88
required :schedule_seq, Float, api_name: :scheduleSeq, nil?: true
|
‘idle` threads can accept a new turn or be closed. `running` threads have an active turn. `awaiting` threads are paused on external input such as approvals. `closed` threads are terminal.
96
|
# File 'lib/cerca/models/thread.rb', line 96
required :status, enum: -> { Cerca::Status }
|
#updated_at ⇒ String
118
|
# File 'lib/cerca/models/thread.rb', line 118
required :updated_at, String, api_name: :updatedAt
|
Class Method Details
.values ⇒ Array<Symbol>
|
# File 'lib/cerca/models/thread.rb', line 182
|