Class: Cerca::Models::ThreadStreamEvent::ThreadStreamStatusMessage
Instance Attribute Summary collapse
Method Summary
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Instance Attribute Details
#error ⇒ String?
35
|
# File 'lib/cerca/models/thread_stream_event.rb', line 35
required :error, String, nil?: true
|
#event_seq ⇒ Float
40
|
# File 'lib/cerca/models/thread_stream_event.rb', line 40
required :event_seq, Float, api_name: :eventSeq
|
#result ⇒ String?
45
|
# File 'lib/cerca/models/thread_stream_event.rb', line 45
required :result, String, nil?: true
|
‘idle` threads can accept a new turn or be closed. `running` threads have an active turn. `awaiting` threads are paused on external input such as approvals. `closed` threads are terminal.
53
|
# File 'lib/cerca/models/thread_stream_event.rb', line 53
required :status, enum: -> { Cerca::Status }
|
#step_seq ⇒ Float
58
|
# File 'lib/cerca/models/thread_stream_event.rb', line 58
required :step_seq, Float, api_name: :stepSeq
|
#turn_id ⇒ String
63
|
# File 'lib/cerca/models/thread_stream_event.rb', line 63
required :turn_id, String, api_name: :turnId
|
#type ⇒ Symbol, :status
68
|
# File 'lib/cerca/models/thread_stream_event.rb', line 68
required :type, const: :status
|