Class: Cerca::Models::ThreadSummary
Overview
Instance Attribute Summary collapse
Instance Method Summary
collapse
-
#initialize(id:, completed_at:, created_at:, message_count:, model:, parent_thread_id:, result:, schedule_id:, schedule_seq:, status:, step_count:) ⇒ Object
constructor
Some parameter documentations has been truncated, see ThreadSummary for more details.
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, completed_at:, created_at:, message_count:, model:, parent_thread_id:, result:, schedule_id:, schedule_seq:, status:, step_count:) ⇒ Object
|
# File 'lib/cerca/models/thread_summary.rb', line 65
|
Instance Attribute Details
#completed_at ⇒ String?
15
|
# File 'lib/cerca/models/thread_summary.rb', line 15
required :completed_at, String, api_name: :completedAt, nil?: true
|
#created_at ⇒ String
20
|
# File 'lib/cerca/models/thread_summary.rb', line 20
required :created_at, String, api_name: :createdAt
|
#id ⇒ String
10
|
# File 'lib/cerca/models/thread_summary.rb', line 10
required :id, String
|
#message_count ⇒ Float
25
|
# File 'lib/cerca/models/thread_summary.rb', line 25
required :message_count, Float, api_name: :messageCount
|
#model ⇒ String
30
|
# File 'lib/cerca/models/thread_summary.rb', line 30
required :model, String
|
#parent_thread_id ⇒ String?
35
|
# File 'lib/cerca/models/thread_summary.rb', line 35
required :parent_thread_id, String, api_name: :parentThreadId, nil?: true
|
#result ⇒ String?
40
|
# File 'lib/cerca/models/thread_summary.rb', line 40
required :result, String, nil?: true
|
#schedule_id ⇒ String?
45
|
# File 'lib/cerca/models/thread_summary.rb', line 45
required :schedule_id, String, api_name: :scheduleId, nil?: true
|
#schedule_seq ⇒ Float?
50
|
# File 'lib/cerca/models/thread_summary.rb', line 50
required :schedule_seq, Float, api_name: :scheduleSeq, nil?: true
|
‘idle` threads can accept a new turn or be closed. `running` threads have an active turn. `awaiting` threads are paused on external input such as approvals. `closed` threads are terminal.
58
|
# File 'lib/cerca/models/thread_summary.rb', line 58
required :status, enum: -> { Cerca::Status }
|
#step_count ⇒ Float
63
|
# File 'lib/cerca/models/thread_summary.rb', line 63
required :step_count, Float, api_name: :stepCount
|