Class: Cerca::Models::WebhookSubscriptionCreated
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Cerca::Models::WebhookSubscriptionCreated
- Defined in:
- lib/cerca/models/webhook_subscription_created.rb
Overview
Instance Attribute Summary collapse
- #created_at ⇒ String
- #enabled ⇒ Boolean
- #events ⇒ Array<Symbol, Cerca::Models::WebhookEventType>
- #fleet_id ⇒ String
- #id ⇒ String
-
#secret ⇒ String
One-time webhook signing secret returned only by create and rotate responses.
- #updated_at ⇒ String
- #url ⇒ String
Instance Method Summary collapse
-
#initialize(id:, created_at:, enabled:, events:, fleet_id:, secret:, updated_at:, url:) ⇒ Object
constructor
Some parameter documentations has been truncated, see WebhookSubscriptionCreated for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, created_at:, enabled:, events:, fleet_id:, secret:, updated_at:, url:) ⇒ Object
Some parameter documentations has been truncated, see Cerca::Models::WebhookSubscriptionCreated for more details.
Webhook subscription response for create and rotate. Includes the one-time ‘secret` field.
|
|
# File 'lib/cerca/models/webhook_subscription_created.rb', line 49
|
Instance Attribute Details
#created_at ⇒ String
15 |
# File 'lib/cerca/models/webhook_subscription_created.rb', line 15 required :created_at, String, api_name: :createdAt |
#enabled ⇒ Boolean
20 |
# File 'lib/cerca/models/webhook_subscription_created.rb', line 20 required :enabled, Cerca::Internal::Type::Boolean |
#events ⇒ Array<Symbol, Cerca::Models::WebhookEventType>
25 |
# File 'lib/cerca/models/webhook_subscription_created.rb', line 25 required :events, -> { Cerca::Internal::Type::ArrayOf[enum: Cerca::WebhookEventType] } |
#fleet_id ⇒ String
30 |
# File 'lib/cerca/models/webhook_subscription_created.rb', line 30 required :fleet_id, String, api_name: :fleetId |
#id ⇒ String
10 |
# File 'lib/cerca/models/webhook_subscription_created.rb', line 10 required :id, String |
#secret ⇒ String
One-time webhook signing secret returned only by create and rotate responses. The field name is ‘secret`.
37 |
# File 'lib/cerca/models/webhook_subscription_created.rb', line 37 required :secret, String |
#updated_at ⇒ String
42 |
# File 'lib/cerca/models/webhook_subscription_created.rb', line 42 required :updated_at, String, api_name: :updatedAt |
#url ⇒ String
47 |
# File 'lib/cerca/models/webhook_subscription_created.rb', line 47 required :url, String |